==> underworld-2.10.1b0.tar.gz: underworld-2.10.1b0/underworld/libUnderworld/StgDomain/Swarm/src/SwarmVariable_Register.c <==
/*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*
**                                                                                  **
** This file forms part of the Underworld geophysics modelling application.         **
**                                                                                  **
** For full license and copyright information, please refer to the LICENSE.md file  **
** located at the project root, or contact the authors.                             **
**                                                                                  **
**~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*/

#include <mpi.h>
#include <StGermain/StGermain.h>

#include <StgDomain/Geometry/Geometry.h>
#include <StgDomain/Shape/Shape.h>
#include <StgDomain/Mesh/Mesh.h>
#include <StgDomain/Utils/Utils.h>

#include "types.h"
#include "SwarmVariable_Register.h"

#include <assert.h>


const Type SwarmVariable_Register_Type = "SwarmVariable_Register";

SwarmVariable_Register*	SwarmVariable_Register_New( Variable_Register* variable_Register ) {
	/* Variables set in this function */
	SizeT                      _sizeOfSelf = sizeof(SwarmVariable_Register);
	Type                              type = SwarmVariable_Register_Type;
	Stg_Class_DeleteFunction*      _delete = _NamedObject_Register_Delete;
	Stg_Class_PrintFunction*        _print = _NamedObject_Register_Print;
	Stg_Class_CopyFunction*          _copy = NULL;

	SwarmVariable_Register* self = (SwarmVariable_Register*) _NamedObject_Register_New(  NAMEDOBJECT_REGISTER_PASSARGS  );

	self->variable_Register = variable_Register;

	return self;
}

==> underworld-2.14.0b0.tar.gz: underworld-2.14.0b0/underworld/libUnderworld/StgDomain/Swarm/src/SwarmVariable_Register.c <==
/*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*
**                                                                                  **
** This file forms part of the Underworld geophysics modelling application.         **
**                                                                                  **
** For full license and copyright information, please refer to the LICENSE.md file  **
** located at the project root, or contact the authors.                             **
**                                                                                  **
**~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*/

#include <mpi.h>
#include <StGermain/libStGermain/src/StGermain.h>

#include <StgDomain/Geometry/src/Geometry.h>
#include <StgDomain/Shape/src/Shape.h>
#include <StgDomain/Mesh/src/Mesh.h>
#include <StgDomain/Utils/src/Utils.h>

#include "types.h"
#include "SwarmVariable_Register.h"

#include <assert.h>


const Type SwarmVariable_Register_Type = "SwarmVariable_Register";

SwarmVariable_Register*	SwarmVariable_Register_New( Variable_Register* variable_Register ) {
	/* Variables set in this function */
	SizeT                      _sizeOfSelf = sizeof(SwarmVariable_Register);
	Type                              type = SwarmVariable_Register_Type;
	Stg_Class_DeleteFunction*      _delete = _NamedObject_Register_Delete;
	Stg_Class_PrintFunction*        _print = _NamedObject_Register_Print;
	Stg_Class_CopyFunction*          _copy = NULL;

	SwarmVariable_Register* self = (SwarmVariable_Register*) _NamedObject_Register_New(  NAMEDOBJECT_REGISTER_PASSARGS  );

	self->variable_Register = variable_Register;

	return self;
}
